@@ -1,5 +1,5 @@
 """
-Copyright (C) 2013-2018 Calliope contributors listed in AUTHORS.
+Copyright (C) since 2013 Calliope contributors listed in AUTHORS.
 Licensed under the Apache 2.0 License (see LICENSE file).
 
 network.py
@@ -15,13 +15,16 @@ ORDER = 10  # order in which to invoke constraints relative to other constraint
 
 
 def load_constraints(backend_model):
-    sets = backend_model.__calliope_model_data['sets']
+    sets = backend_model.__calliope_model_data["sets"]
     run_config = backend_model.__calliope_run_config
 
-    if 'loc_techs_symmetric_transmission_constraint' in sets and run_config['mode'] != 'operate':
+    if (
+        "loc_techs_symmetric_transmission_constraint" in sets
+        and run_config["mode"] != "operate"
+    ):
         backend_model.symmetric_transmission_constraint = po.Constraint(
             backend_model.loc_techs_symmetric_transmission_constraint,
-            rule=symmetric_transmission_constraint_rule
+            rule=symmetric_transmission_constraint_rule,
         )
 
 
@@ -36,7 +39,9 @@ def symmetric_transmission_constraint_rule(backend_model, loc_tech):
             energy_{cap}(loc1::tech:loc2) = energy_{cap}(loc2::tech:loc1)
 
     """
-    lookup = backend_model.__calliope_model_data['data']['lookup_remotes']
+    lookup = backend_model.__calliope_model_data["data"]["lookup_remotes"]
     loc_tech_remote = lookup[loc_tech]
 
-    return backend_model.energy_cap[loc_tech] == backend_model.energy_cap[loc_tech_remote]
+    return (
+        backend_model.energy_cap[loc_tech] == backend_model.energy_cap[loc_tech_remote]
+    )
